==> haskell-data-default-instances-dlist-0.0.1-27-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-data-default-instances-dlist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-default-instances-dlist
version: 0.0.1
id: data-default-instances-dlist-0.0.1-GGmGGHeumpsJkK5tXKqXXv
key: data-default-instances-dlist-0.0.1-GGmGGHeumpsJkK5tXKqXXv
license: BSD-3-Clause
maintainer: <l.mai@web.de>
author: Lukas Mai
synopsis: Default instances for types in dlist
category: Data
abi: b2bbecfce1acd61fa41491430ecd68d3
exposed: True
exposed-modules:
    Data.Default.Instances.DList
import-dirs: /usr/lib/ghc-8.4.3/site-local/data-default-instances-dlist-0.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/data-default-instances-dlist-0.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/data-default-instances-dlist-0.0.1
hs-libraries: HSdata-default-instances-dlist-0.0.1-GGmGGHeumpsJkK5tXKqXXv
depends:
    base-4.11.1.0 data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j
    dlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j=64b4bc7e44050b1acf530e79a106effe
             dlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD=d8185cdeb1f72c3606ef0c9fb78dc6d0
haddock-interfaces: /usr/share/doc/haskell-data-default-instances-dlist/html/data-default-instances-dlist.haddock
haddock-html: /usr/share/doc/haskell-data-default-instances-dlist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-default-instances-dlist-0.0.1-28-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-data-default-instances-dlist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-default-instances-dlist
version: 0.0.1
id: data-default-instances-dlist-0.0.1-AHcGTNiXruW3PEDvkkFNp5
key: data-default-instances-dlist-0.0.1-AHcGTNiXruW3PEDvkkFNp5
license: BSD-3-Clause
maintainer: <l.mai@web.de>
author: Lukas Mai
synopsis: Default instances for types in dlist
category: Data
abi: 395d1887b953adc9498865c6058512ff
exposed: True
exposed-modules:
    Data.Default.Instances.DList
import-dirs: /usr/lib/ghc-8.4.3/site-local/data-default-instances-dlist-0.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/data-default-instances-dlist-0.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/data-default-instances-dlist-0.0.1
hs-libraries: HSdata-default-instances-dlist-0.0.1-AHcGTNiXruW3PEDvkkFNp5
depends:
    base-4.11.1.0 data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j
    dlist-0.8.0.5-6LWFCfMSEKNIqqazR8mrr6
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j=64b4bc7e44050b1acf530e79a106effe
             dlist-0.8.0.5-6LWFCfMSEKNIqqazR8mrr6=a89500558697401c3bf5eb58146baa5c
haddock-interfaces: /usr/share/doc/haskell-data-default-instances-dlist/html/data-default-instances-dlist.haddock
haddock-html: /usr/share/doc/haskell-data-default-instances-dlist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
